==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/es/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "El template $1 está en uso y no puede eliminarse.");
regGS("The folder could not be deleted.", "El directorio no pudo ser borrado");
regGS("The directory must be empty", "El directorio debe estar vacío");
regGS("Create new folder", "Crear nuevo directorio");
regGS("Upload template", "Subir plantilla");
regGS("Creating new folder", "Crear nuevo directorio");
regGS("You do not have the right to create new folders.", "No tiene derecho para crear nuevos directorios");
regGS("The folder $1 could not be created", "El directorio $1 no pudo ser creado");
regGS("A file or folder having the name $1 already exists", "Ya existe un archivo o folder con el nombre $1");
regGS("You do not have the right to delete templates.", "No tiene derechos para borrar plantillas");
regGS("Are you sure you want to delete the folder $1 from $2?", "Esta seguro que desea borrar el directorio $1 de $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Esta seguro que desea borrar la plantilla $1 del directorio $2?");
regGS("Deleting template", "Borrando plantillas");
regGS("Deleting folder", "Borrando directorios");
regGS("Template $1 was deleted", "El template $1 fue eliminado");
regGS("Delete folder", "Borrar directorio");
regGS("Folders", "Directorios");
regGS("No folders.", "Sin directorios");
regGS("Files", "Archivos");
regGS("No templates.", "Sin plantillas");
regGS("Uploading template", "Subiendo plantillas");
regGS("File", "Archivo");
regGS("Create new template", "Crear nueva plantilla");
regGS("Creating new template", "Creando nuevas plantillas");
regGS("Duplicate template", "Duplicar plantilla");
regGS("Edit template", "Editar plantilla");
regGS("The template $1 has been created.", "La plantilla $1 ha sido creada");
regGS("Do you want to edit the template ?", "¿Desea editar la plantilla?");
regGS("The template $1 could not be created.", "La plantilla $1 no pudo ser creada");
regGS("Template $1 was changed", "La plantilla $1 fue cambiada");
regGS("New template $1 was created", "Nueva plantilla $1 fue creada");
regGS("Template $1 was duplicated into $2", "Plantilla $1 fue duplicada a $2");
regGS("Template charset", "Plantilla charset");
regGS("Select a language/character set", "Seleccione un idioma/charset");
regGS("All languages", "Todos los idiomas");
regGS("You do not have the right to modify templates.", "No tiene privilegios para modificar templates.");
regGS("Invalid template file $1", "El archivo de template $1 es inválido");
regGS("You do not have the right to create folders.", "No tiene privilegios para crear folders.");
regGS("You do not have the right to upload templates.", "No tiene privilegios para cargar templates.");
regGS("You do not have the right to create templates.", "No tiene privilegios para crear templates.");
regGS("Duplicate file", "Archivo duplicado");
regGS("Delete file", "Elimine archivo");
regGS("Unable to save the template '$1' to the path '$2'.", "No es posible guardar el template '$1' en el path '$2'");
regGS("Please check if the user '$1' has permission to write in this directory.", "Por favor verifique que el usuario '$1' tiene privilegio para escribir en este directorio.");
regGS("Unable to delete the template '$1' in the path '$2'.", "No es posible eliminar el template '$1' en el path '$2'");
regGS("The folder has been deleted.", "El directorio ha sido borrado");
regGS("The template has been deleted.", "La plantilla ha sido borrada");
regGS("The template could not be deleted.", "La plantilla no pudo ser borrada");
regGS("Save", "Grabar");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/es/templates.php <==
<?php 
regGS("Template ID:", "ID de la plantilla:");
regGS("Template ID", "ID de la plantilla");
regGS("Template $1 no longer exists!", "La plantilla '$1' ya no existe");
regGS("New template $1 created", "Se creó la nueva plantilla '$1' ");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "Si el archivo que especificó es de texto, puede convertir sus caracteres usando el menú dropdown que aparece abajo.");
regGS("Directory $1 was deleted", "Se eliminó el directorio '$1' ");
regGS("Directory $1 created.", "Se creó el directorio '$1' ");
regGS("You must select a file to upload.", "Debe seleccionar un archivo para cargar");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "Solo puede reemplazar un archivo con otro del mismo tipo.  El archivo original es de tipo \"$1\", y el que cargó es del tipo \"$2\".");
regGS("Unable to save the file '$1' to the path '$2'.", "No fue posible almacenar el archivo '$1' al path '$2'");
regGS("Replace file:", "Reemplazar el archivo:");
regGS("Replace", "Reemplazar");
regGS("File \"$1\" uploaded.", "Se cargó el archivo \"$1\"");
regGS("File \"$1\" replaced.", "Se reemplazo el archivo \"$1\".");
regGS("The folder name can't be '..' or '.'", "El nombre del folder no puede ser '..' o '.'");
regGS("The template '$1' was saved successfully.", "La plantilla '$1' se almacenó con éxito");
regGS("The template $1 is in use and can not be deleted.", "El template $1 está en uso y no puede eliminarse.");
regGS("Create new folder", "Crear nuevo directorio");
regGS("Upload template", "Subir plantilla");
regGS("You do not have the right to create new folders.", "No tiene derecho para crear nuevos directorios");
regGS("A file or folder having the name $1 already exists", "Ya existe un archivo o folder con el nombre $1");
regGS("You do not have the right to delete templates.", "No tiene derechos para borrar plantillas");
regGS("Are you sure you want to delete the folder $1 from $2?", "Esta seguro que desea borrar el directorio $1 de $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Esta seguro que desea borrar la plantilla $1 del directorio $2?");
regGS("Template $1 was deleted", "El template $1 fue eliminado");
regGS("Delete folder", "Borrar directorio");
regGS("Folders", "Directorios");
regGS("No folders.", "Sin directorios");
regGS("Files", "Archivos");
regGS("No templates.", "Sin plantillas");
regGS("File", "Archivo");
regGS("Create new template", "Crear nueva plantilla");
regGS("Duplicate template", "Duplicar plantilla");
regGS("Edit template", "Editar plantilla");
regGS("The template $1 could not be created.", "La plantilla $1 no pudo ser creada");
regGS("Template $1 was changed", "La plantilla $1 fue cambiada");
regGS("Template $1 was duplicated into $2", "Plantilla $1 fue duplicada a $2");
regGS("Template charset", "Plantilla charset");
regGS("Select a language/character set", "Seleccione un idioma/charset");
regGS("All languages", "Todos los idiomas");
regGS("You do not have the right to modify templates.", "No tiene privilegios para modificar templates.");
regGS("Invalid template file $1", "El archivo de template $1 es inválido");
regGS("You do not have the right to create folders.", "No tiene privilegios para crear folders.");
regGS("You do not have the right to upload templates.", "No tiene privilegios para cargar templates.");
regGS("You do not have the right to create templates.", "No tiene privilegios para crear templates.");
regGS("Duplicate file", "Archivo duplicado");
regGS("Delete file", "Elimine archivo");
regGS("Please check if the user '$1' has permission to write in this directory.", "Por favor verifique que el usuario '$1' tiene privilegio para escribir en este directorio.");
regGS("The folder has been deleted.", "El directorio ha sido borrado");
regGS("The template has been deleted.", "La plantilla ha sido borrada");
regGS("The template could not be deleted.", "La plantilla no pudo ser borrada");
regGS("Save", "Grabar");
?>
